;; Generated package description from cobol-mode.el  -*- no-byte-compile: t -*-
(define-package "cobol-mode" "1.1" "Mode for editing COBOL code" '((cl-lib "0.5")) :commit "bd7879daa71908616277688ba51d27b60c88b0a2" :url "https://elpa.gnu.org/packages/cobol-mode.html" :authors '(("Edward Hart" . "edward.dan.hart@gmail.com")) :maintainer '("Edward Hart" . "edward.dan.hart@gmail.com") :keywords '("languages"))
